This is method for Pwr() generic function. It is a modified version from the
one described by Galecki and Burzykowski implemented in nlmeU package (nlmeU::Pwr.lme).
# S3 method for lme
Pwr(
object,
...,
type = c("sequential", "marginal"),
Terms,
L,
verbose = FALSE,
sigma,
ddf = numeric(0),
alpha = 0.05,
altB = NULL,
tol = 1e-10
)a data frame inheriting from class Pwr.lme
an object containing lme fit, which provides information needed for power calculations
some additional arguments may be required.
an optional character string specifying the type of sum of squares to be used in F-tests
needed for power calculations. Syntax is the same as for anova.lme() in nlme package.
an optional integer or character vector specifying which terms
in the model should be jointly tested to be zero using a Wald F-test. See
anova.lme in nlme package for details.
an optional numeric vector or array specifying linear combinations
of the coefficients in the model that should be tested to be zero. See
anova.lme in nlme package for details.
an optional logical value. See anova.lme in nlme package for details.
numeric scalar value.
numeric scalar value. Argument can be used to redefine default number of denominator degrees of freedom
numeric scalar value. By default 0.05.
matrix/vector containing alternative values for beta parameters
numeric scalar value.
Andrzej Galecki & Tomasz Burzykowski (2013) Linear Mixed-Effects Models Using R: A Step-by-Step Approach First Edition. Springer, New York. ISBN 978-1-4614-3899-1
nlme::anova.lme, nlmeU::Pwr.lme